@@ -33,6 +33,52 @@ void MainWindow::grabZoomKeys(bool grab)
                  1);
      }
 
+void MainWindow::inet(QListWidgetItem* item){
+inet_source=1;
+
+
+    moo->setCurrentSource(ilist.value(ui.listWidget_2->currentRow()).at(0));
+    moo->play();
+
+
+
+}
+
+void MainWindow::load_inet(){
+
+QFile file("/home/user/tplayer-inet.m3u");
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+            return;
+
+
+
+QTextStream in(&file);
+
+
+     QString line = in.readLine();
+
+      if (line!="#EXTM3U")return;
+
+int t=0;
+        while (!in.atEnd()) {
+
+           line = in.readLine();
+
+
+           QRegExp rx("^#EXTINF:\\d*,(.*)$") ;
+           rx.indexIn(line);
+           QString title=rx.cap(1);
+           line = in.readLine();
+           ilist.insert(t++,QStringList()<<line<<title<<"Internet radio");
+
+              ui.listWidget_2->addItem(title);
+        }
+
+
+        ui.pushButton_16->setEnabled(true);
+}
+
+
 
 void MainWindow::headphoneEvent(QString what,QString how)
 {
@@ -157,7 +203,8 @@ load();
 //opt->load(rotate,ui.listWidget->font().toString(),listWidget->font().pointSize());
 
 
-
+/*
+ old style menu
 mmenu=new QMenu ();
 QMenu *mmenut=new QMenu ("Tools");
 mmenut->addAction("Download art",this,SLOT(dart()));
@@ -169,6 +216,29 @@ mmenu->addAction("About",this,SLOT(about()));
 mmenu->addAction("Quit",qApp,SLOT(quit()));
 
 
+*/
+
+//new style
+ui.frame_10->hide();
+connect (ui.pushButton_17,SIGNAL(clicked()),this,SLOT(about()));
+connect (ui.pushButton_14,SIGNAL(clicked()),this,SLOT(click6()));
+connect (ui.pushButton_15,SIGNAL(clicked()),this,SLOT(click7()));
+connect (ui.pushButton_16,SIGNAL(clicked()),this,SLOT(click8()));
+
+connect (ui.pushButton_19,SIGNAL(clicked()),this,SLOT(dart()));
+connect (ui.pushButton_20,SIGNAL(clicked()),this,SLOT(dart2()));
+connect (ui.pushButton_21,SIGNAL(clicked()),opt,SLOT(exec()));
+connect (ui.checkBox_2,SIGNAL(stateChanged(int)),this,SLOT(fmtx_change(int)));
+
+connect(ui.listWidget_2,SIGNAL(itemDoubleClicked(QListWidgetItem*)),this,SLOT(inet(QListWidgetItem*)));
+
+connect(ui.pushButton_23,SIGNAL(clicked()),this,SLOT(i_fn_click()));
+connect (ui.pushButton_22,SIGNAL(clicked()),this,SLOT(inform()));
+//
+
+load_inet();
+
+
 
 connect(ui.pushButton_10,SIGNAL(clicked()),this,SLOT(pl_sf_click()));
 
@@ -189,7 +259,7 @@ connect (opt,SIGNAL(accepted()),this,SLOT(load()));
           connect(moo,SIGNAL(stateChanged(Phonon::State,Phonon::State)),this,SLOT(changePlay(Phonon::State,Phonon::State)));
           connect(ui.listWidget,SIGNAL(itemDoubleClicked(QListWidgetItem*)),this,SLOT(currentItemChanged(QListWidgetItem*)));
           connect(moo,SIGNAL(finished()),this,SLOT(next()));
-          connect (ui.pushButton_12,SIGNAL(clicked()),mmenu,SLOT(show()));
+
 click1();
 
 
@@ -492,9 +562,9 @@ orientationChanged();
 
 void MainWindow::orientationChanged()
 {
-
+/*
     QRect screenGeometry = QApplication::desktop()->screenGeometry();
-    /*if (screenGeometry.width() > screenGeometry.height())
+    if (screenGeometry.width() > screenGeometry.height())
     {
         //land
         QHBoxLayout *y=new QHBoxLayout(ui.widget);
@@ -556,6 +626,51 @@ void MainWindow::kbdhelp(){
 dg->exec();
 }
 
+void MainWindow::fmtx_change(int state){
+    try{
+
+    if (state==Qt::Checked){
+        // enable
+
+        QString txt=ui.lineEdit_2->text();
+        if (inet_source!=1){
+        txt.replace("%artist",list.value(ui.listWidget->currentRow()).at(2));
+        txt.replace("%track",list.value(ui.listWidget->currentRow()).at(1));}
+        else{
+
+            QMap<QString, QString> metaData = moo->metaData();
+
+            QString title = metaData.value("ORGANIZATION");
+            if (title == "")
+                title =moo->currentSource().url().toString();
+
+        QString artist = metaData.value("LOCATION");
+
+        txt.replace("%artist",title);
+        txt.replace("%track",artist);
+        }
+        system(QString("fmtx_client -f %1 -s \"%2\" -t \"%3\" -p 1 >/dev/zero  2>/dev/zero").arg((int)(ui.doubleSpinBox->value()*1000)).arg(ui.lineEdit->text()).arg(txt).toAscii());
+        system("sudo /sbin/fm-boost");
+
+        ui.doubleSpinBox->setEnabled(false);
+        ui.lineEdit->setEnabled(false);
+        ui.lineEdit_2->setEnabled(false);
+
+    }else{
+        //disable
+
+        system("fmtx_client -p 0 >/dev/zero  2>/dev/zero");
+
+        ui.doubleSpinBox->setEnabled(true);
+        ui.lineEdit->setEnabled(true);
+        ui.lineEdit_2->setEnabled(true);
+    }
+}catch(int e){
+
+}
+
+}
+
 MainWindow::~MainWindow()
 {
 db.commit();
@@ -655,7 +770,7 @@ void MainWindow::clear(){
 
 
 void MainWindow::next(){
-
+    if (inet_source!=1){
     if ((float)moo->currentTime()/(float)moo->totalTime()>0.5)
         scrobler->addTrack(list.value(ui.listWidget->currentRow()),moo->totalTime());
 
@@ -667,10 +782,16 @@ if (ui.listWidget->count()==0)return;
 
      moo->setCurrentSource(list.value(ui.listWidget->currentRow()).at(0));
     moo->play();
+}else{
+    QMessageBox g;
+    g.setText("Not allowed for intrnet streams");
+    g.exec();
+}
 
 }
 
 void MainWindow::prev(){
+    if (inet_source!=1){
     if (moo->currentTime()/moo->totalTime()>0.5)
         scrobler->addTrack(list.value(ui.listWidget->currentRow()),moo->totalTime());
 
@@ -682,6 +803,11 @@ if (ui.listWidget->count()==0)return;
 
     moo->setCurrentSource(list.value(ui.listWidget->currentRow()).at(0));
     moo->play();
+}else{
+    QMessageBox g;
+    g.setText("Not allowed for intrnet streams");
+    g.exec();
+}
 
 }
 
@@ -692,6 +818,7 @@ void MainWindow::play_pause(){
 }
 
 void MainWindow::currentItemChanged ( QListWidgetItem * current ){
+    inet_source=0;
     if (moo->currentTime()/moo->totalTime()>0.5)
         scrobler->addTrack(list.value(ui.listWidget->currentRow()),moo->totalTime());
 
@@ -703,6 +830,8 @@ void MainWindow::currentItemChanged ( QListWidgetItem * current ){
 
 
 void MainWindow::changePlay( Phonon::State newstate, Phonon::State oldstate ) {
+    try{
+        if (inet_source==0){
     ui.label->setText(list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1));
     this->setWindowTitle(list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1));
     if (newstate==Phonon::PlayingState&&oldstate!=Phonon::PausedState){
@@ -719,6 +848,16 @@ connect(box,SIGNAL(clicked()),this,SLOT(setFocus()));
 box->exec();}
 #endif
  }
+    // fmtx
+    if (ui.checkBox_2->isChecked()){
+    QString txt=ui.lineEdit_2->text();
+    txt.replace("%artist",list.value(ui.listWidget->currentRow()).at(2));
+    txt.replace("%track",list.value(ui.listWidget->currentRow()).at(1));
+    system(QString("fmtx_client -s \"%2\" -t \"%3\" >/dev/zero  2>/dev/zero").arg(ui.lineEdit->text()).arg(txt).toAscii());
+    system("sudo /sbin/fm-boost");
+}
+
+
     /*
      iload - loading state variable
      0- no load
@@ -752,6 +891,8 @@ box->exec();}
                 dart();
             }
         }
+
+
 }
 ui.textEdit->setText("");
 ui.textEdit_2->setText("");
@@ -800,6 +941,45 @@ ui.textEdit_2->setText("");
         file2.close();
         }
 
+        ui.pushButton_19->setEnabled(true);
+    }else{
+
+
+        QMap<QString, QString> metaData = moo->metaData();
+
+        QString title = metaData.value("ORGANIZATION");
+        if (title == "")
+            title =moo->currentSource().url().toString();
+
+    QString artist = metaData.value("LOCATION");
+
+
+
+        ui.label->setText(title+" - "+artist);
+        this->setWindowTitle(title+" - "+artist);
+        if (newstate==Phonon::PlayingState&&oldstate!=Phonon::PausedState){
+
+  #ifdef Q_WS_MAEMO_5
+       if (!this->isActiveWindow()){
+       QMaemo5InformationBox *box=new QMaemo5InformationBox();
+       QLabel *lbl=new QLabel("Now playing :"+title+" - "+artist,box);
+      box->setWidget (lbl);
+    box->setTimeout(3000);
+    connect(box,SIGNAL(clicked()),this,SLOT(setFocus()));
+    box->exec();}
+    #endif
+
+
+       QPixmap *t=new QPixmap(":/icons/inet.png");
+       ui.image->setPixmap(t->scaled(400,300,Qt::KeepAspectRatio,Qt::FastTransformation));
+
+ui.pushButton_19->setEnabled(false);
+    }
+
+    }
+    }catch(int e){
+
+    }
 }
 
 void MainWindow::replyFinished(QNetworkReply*reply){
@@ -867,10 +1047,14 @@ if (list.value(ui.listWidget->currentRow()).at(4)!="Unknown")
 }
 
 void MainWindow::dart2(){
+    QMessageBox f;
+    f.setText("This process will start in background\n Just wait when inet request speed slow down to zero\nI will create an progress bar in nearest future");
+    f.exec();
     for (int i=0;i<ui.listWidget->count();i++){
         ui.listWidget->setCurrentRow(i);
         dart();
     }
+
 }
 
 
@@ -987,6 +1171,8 @@ mv.addAction("Find",this,SLOT(find()));
 
 
 
+
+
 void MainWindow::find(){
     bool ok;
          QString text = QInputDialog::getText(this, tr("Searching "),
@@ -1004,6 +1190,33 @@ void MainWindow::find(){
          }
 }
 
+
+void MainWindow::i_fn_click(){
+QMenu fh;
+
+fh.addAction("To begin",ui.listWidget_2,SLOT(scrollToTop()));
+fh.addAction("To end",ui.listWidget_2,SLOT(scrollToBottom()));
+fh.addAction("Find",this,SLOT(findi()));
+fh.exec(QCursor::pos());
+}
+
+void MainWindow::findi(){
+    bool ok;
+         QString text = QInputDialog::getText(this, tr("Searching "),
+                                              tr("Part from name:"), QLineEdit::Normal,
+                                              "", &ok);
+         if (ok && !text.isEmpty())
+         {
+             QMapIterator<int,QStringList> i(ilist);
+             while(i.hasNext()){
+                 if (i.next().value().join(" ").toLower().indexOf(text.toLower())!=-1){
+                     ui.listWidget_2->setCurrentRow(i.key());
+                     return;
+                 }
+             }
+         }
+}
+
 void MainWindow::pl_fn_add_dir(){
     int l=0;
     ld=new QDialog();
@@ -1094,6 +1307,8 @@ list.clear();
 
 }
 
+
+
 void MainWindow::getMeta(QString path){
 queue.append(path);
 }
@@ -1104,6 +1319,9 @@ void MainWindow::click1(){
     ui.frame_6->hide();
     ui.frame_7->hide();
     ui.frame_8->hide();
+    ui.frame_11->hide();
+    ui.frame_12->hide();
+    ui.frame_13->hide();
 
 }
 
@@ -1113,6 +1331,9 @@ void MainWindow::click2(){
     ui.frame_6->hide();
     ui.frame_7->hide();
     ui.frame_8->hide();
+    ui.frame_11->hide();
+    ui.frame_12->hide();
+    ui.frame_13->hide();
 }
 void MainWindow::click3(){
     ui.frame_2->hide();
@@ -1120,6 +1341,9 @@ void MainWindow::click3(){
     ui.frame_6->show();
     ui.frame_7->hide();
     ui.frame_8->hide();
+    ui.frame_11->hide();
+    ui.frame_12->hide();
+    ui.frame_13->hide();
 }
 void MainWindow::click4(){
     ui.frame_2->hide();
@@ -1127,6 +1351,9 @@ void MainWindow::click4(){
     ui.frame_6->hide();
     ui.frame_7->hide();
     ui.frame_8->show();
+    ui.frame_11->hide();
+    ui.frame_12->hide();
+    ui.frame_13->hide();
 }
 void MainWindow::click5(){
     ui.frame_2->hide();
@@ -1134,4 +1361,40 @@ void MainWindow::click5(){
     ui.frame_6->hide();
     ui.frame_7->show();
     ui.frame_8->hide();
+    ui.frame_11->hide();
+    ui.frame_12->hide();
+    ui.frame_13->hide();
+}
+
+void MainWindow::click6(){
+    ui.frame_2->hide();
+    ui.frame_4->hide();
+    ui.frame_6->hide();
+    ui.frame_7->hide();
+    ui.frame_8->hide();
+    ui.frame_11->show();
+    ui.frame_12->hide();
+    ui.frame_13->hide();
+}
+
+void MainWindow::click7(){
+    ui.frame_2->hide();
+    ui.frame_4->hide();
+    ui.frame_6->hide();
+    ui.frame_7->hide();
+    ui.frame_8->hide();
+    ui.frame_11->hide();
+    ui.frame_12->show();
+    ui.frame_13->hide();
+}
+
+void MainWindow::click8(){
+    ui.frame_2->hide();
+    ui.frame_4->hide();
+    ui.frame_6->hide();
+    ui.frame_7->hide();
+    ui.frame_8->hide();
+    ui.frame_11->hide();
+    ui.frame_12->hide();
+    ui.frame_13->show();
 }
